package org.projectepic.filters;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.app.ProgressDialog;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;

public class Main extends Activity implements OnClickListener {
	 
	private GetFilters get_filters_task;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, R.layout.menu_item);
    	adapter.add("No Filters");
        
        ListView filters = (ListView) findViewById(R.id.filters);
        filters.setAdapter(adapter);
        
        Button get_button =  (Button) findViewById(R.id.get_filters);
        
        get_button.setOnClickListener(this);

    }
    
    public void onClick(View v) {
    	switch (v.getId()) {
    	    case R.id.get_filters:
    	        get_filters_task = new GetFilters();
    	        get_filters_task.execute();
        		break;
    	}
    }
    
    private class GetFilters extends AsyncTask<Object, String, Boolean> {
    	private ProgressDialog progressDialog;
    	
    	@Override
    	protected void onPreExecute() {
    		progressDialog = ProgressDialog.show(Main.this, "Project EPIC Filters", "Downloading active filters...", true, true);
    	}
    	
    	@Override
    	protected void onPostExecute(Boolean result) {
    		progressDialog.dismiss();
    	}

		@Override
		protected Boolean doInBackground(Object... params) {
			HttpURLConnection con = null;
			try {
				URL url = new URL("http://epic-vm2:8080/api/queries/twitter/filters");
				
				con = (HttpURLConnection) url.openConnection();
				con.setReadTimeout(10000);
				con.setConnectTimeout(15000);
				
				con.setRequestMethod("GET" );
				
				con.setDoInput(true);
				
				con.connect();
				
				BufferedReader reader = new BufferedReader( new InputStreamReader(con.getInputStream(), "UTF-8"));
				String payload = reader.readLine();
				reader.close();
				// Parse to get translated text
				JSONObject jsonObject = new JSONObject(payload);
				JSONArray items = jsonObject.getJSONArray("items");
				int length = items.length();
				String[] filters = new String[length];
				
				for (int i = 0; i < length; i++) {
					JSONObject filter = items.getJSONObject(i);
					filters[i] = filter.getString("query");
				}
				
				publishProgress(filters);
				
				
			} catch (MalformedURLException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (JSONException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			return true;
		}
		
	    @Override
	    protected void onProgressUpdate(String... values) {
	        ArrayAdapter<String> adapter = new ArrayAdapter<String>(Main.this, R.layout.menu_item);
	        for (String filter : values) {
	        	adapter.add(filter);
	        }
	        ListView filters = (ListView) Main.this.findViewById(R.id.filters);
	        filters.setAdapter(adapter);
	        
	    }

    }

}